@@ -3,6 +3,8 @@
 
 const { Clutter, GLib, Gio, St } = imports.gi;
 
+const Params = imports.misc.params;
+
 var ANIMATED_ICON_UPDATE_TIMEOUT = 16;
 var SPINNER_ANIMATION_TIME = 300;
 var SPINNER_ANIMATION_DELAY = 1000;
@@ -131,12 +133,22 @@ var AnimatedIcon = class extends Animation {
 };
 
 var Spinner = class extends AnimatedIcon {
-    constructor(size, animate = false) {
+    constructor(size, params) {
+        // Compatibility with older callers
+        if (params === true || params === false)
+            params = { animate: params };
+
+        params = Params.parse(params, {
+            animate: false,
+            hideOnStop: false,
+        });
         let file = Gio.File.new_for_uri('resource:///org/gnome/shell/theme/process-working.svg');
         super(file, size);
 
         this.actor.opacity = 0;
-        this._animate = animate;
+        this._animate = params.animate;
+        this._hideOnStop = params.hideOnStop;
+        this.actor.visible = !this._hideOnStop;
     }
 
     _onDestroy() {
@@ -146,6 +158,7 @@ var Spinner = class extends AnimatedIcon {
 
     play() {
         this.actor.remove_all_transitions();
+        this.actor.show();
 
         if (this._animate) {
             super.play();
@@ -167,13 +180,20 @@ var Spinner = class extends AnimatedIcon {
         if (this._animate) {
             this.actor.ease({
                 opacity: 0,
-                time: SPINNER_ANIMATION_TIME,
-                transition: 'linear',
-                onComplete: () => super.stop()
+                duration: SPINNER_ANIMATION_TIME,
+                mode: Clutter.AnimationMode.LINEAR,
+                onComplete: () => {
+                    super.stop();
+                    if (this._hideOnStop)
+                        this.actor.hide();
+                },
             });
         } else {
             this.actor.opacity = 0;
             super.stop();
+
+            if (this._hideOnStop)
+                this.actor.hide();
         }
     }
 };
