@@ -1,6 +1,5 @@
-const Clutter = imports.gi.Clutter;
-const Pango = imports.gi.Pango;
-const St = imports.gi.St;
+/* exported CheckBox */
+const { Clutter, Pango, St } = imports.gi;
 
 var CheckBox = class CheckBox {
     constructor(label) {
