@@ -27,24 +27,24 @@ class KbdA11yDialog extends GObject.Object {
 
         if (whatChanged & Clutter.KeyboardA11yFlags.SLOW_KEYS_ENABLED) {
             key = KEY_SLOW_KEYS_ENABLED;
-            enabled = (newFlags & Clutter.KeyboardA11yFlags.SLOW_KEYS_ENABLED) ? true : false;
-            title = enabled ?
-                    _("Slow Keys Turned On") :
-                    _("Slow Keys Turned Off");
+            enabled = (newFlags & Clutter.KeyboardA11yFlags.SLOW_KEYS_ENABLED) > 0;
+            title = enabled
+                ? _("Slow Keys Turned On")
+                : _("Slow Keys Turned Off");
             body = _("You just held down the Shift key for 8 seconds. This is the shortcut " +
                      "for the Slow Keys feature, which affects the way your keyboard works.");
 
         } else  if (whatChanged & Clutter.KeyboardA11yFlags.STICKY_KEYS_ENABLED) {
             key = KEY_STICKY_KEYS_ENABLED;
-            enabled = (newFlags & Clutter.KeyboardA11yFlags.STICKY_KEYS_ENABLED) ? true : false;
-            title = enabled ?
-                    _("Sticky Keys Turned On") :
-                    _("Sticky Keys Turned Off");
-            body = enabled ?
-                   _("You just pressed the Shift key 5 times in a row. This is the shortcut " +
-                     "for the Sticky Keys feature, which affects the way your keyboard works.") :
-                   _("You just pressed two keys at once, or pressed the Shift key 5 times in a row. " +
-                     "This turns off the Sticky Keys feature, which affects the way your keyboard works.");
+            enabled = (newFlags & Clutter.KeyboardA11yFlags.STICKY_KEYS_ENABLED) > 0;
+            title = enabled
+                ? _("Sticky Keys Turned On")
+                : _("Sticky Keys Turned Off");
+            body = enabled
+                ? _("You just pressed the Shift key 5 times in a row. This is the shortcut " +
+                  "for the Sticky Keys feature, which affects the way your keyboard works.")
+                : _("You just pressed two keys at once, or pressed the Shift key 5 times in a row. " +
+                  "This turns off the Sticky Keys feature, which affects the way your keyboard works.");
         } else {
             return;
         }
