@@ -2,9 +2,7 @@
 
 const UI = imports.testcommon.ui;
 
-const Clutter = imports.gi.Clutter;
-const Gtk = imports.gi.Gtk;
-const St = imports.gi.St;
+const { Clutter, Gtk, St } = imports.gi;
 
 function test() {
     let stage = new Clutter.Stage();
@@ -23,7 +21,7 @@ function test() {
     let v = new St.ScrollView();
     vbox.add(v, { expand: true });
 
-    toggle.connect('notify::checked', function () {
+    toggle.connect('notify::checked', () => {
         v.set_policy(toggle.checked ? Gtk.PolicyType.AUTOMATIC
                      : Gtk.PolicyType.NEVER,
                      Gtk.PolicyType.AUTOMATIC);
